@@ -24,6 +24,7 @@ extern NSString *const VLCPlaybackControllerPlaybackPositionUpdated;
 
 @class VLCPlaybackController;
 @class VLCMetaData;
+@class VLCDialogProvider;
 
 @protocol VLCPlaybackControllerDelegate <NSObject>
 @optional
@@ -90,6 +91,7 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
 @property (readonly) NSNumber *playbackTime;
 @property (nonatomic, readonly) NSDictionary *mediaOptionsDictionary;
 @property (nonatomic, readonly) NSTimer *sleepTimer;
+@property (nonatomic, readonly) VLCDialogProvider *dialogProvider;
 
 @property (nonatomic) VLCRendererItem * _Nullable renderer;
 
@@ -120,7 +122,7 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
 - (void)setAudioPassthrough:(BOOL)shouldPass;
 
 - (void)switchAspectRatio;
-- (void)switchIPhoneXFullScreen;
+- (void)toggleFullScreen;
 #if !TARGET_OS_TV
 - (BOOL)updateViewpoint:(CGFloat)yaw pitch:(CGFloat)pitch roll:(CGFloat)roll fov:(CGFloat)fov absolute:(BOOL)absolute;
 - (NSInteger)currentMediaProjection;
@@ -128,6 +130,8 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
 - (void)recoverDisplayedMetadata;
 - (void)recoverPlaybackState;
 
+- (BOOL)isPlayingOnExternalScreen;
+
 - (void)setNeedsMetadataUpdate;
 - (void)scheduleSleepTimerWithInterval:(NSTimeInterval)timeInterval;
 - (void)performNavigationAction:(VLCMediaPlaybackNavigationAction)action;
